GoldenCoveragePlan class

Annotations

Constructors

GoldenCoveragePlan({required int rawCount, required int excludedCount, required GoldenSampling sampling, required List<GoldenVariant> variants})
const

Properties

excludedCount int
final
hashCode int
The hash code for this object.
no setterinherited
rawCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampling GoldenSampling
final
selectedCount int
no setter
variants List<GoldenVariant>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited