GoldenPathStrategy class

Constructors

GoldenPathStrategy({String folder = 'golden', bool includeDefaultAxes = false})
const

Properties

folder String
final
hashCode int
The hash code for this object.
no setterinherited
includeDefaultAxes bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build({required String scenario, required GoldenVariant variant, String testName = ''}) String
collisions({required String scenario, required Iterable<GoldenVariant> variants, String testName = ''}) Map<String, List<GoldenVariant>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate({required String scenario, required Iterable<GoldenVariant> variants, String testName = ''}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited