GoldenTestContext class
Properties
- captureFinder → Finder
-
final
-
captures
→ List<
GoldenCapture> -
no setter
- configuration → GoldenRunConfiguration
-
final
- diagnostics → GoldenDiagnostics
-
final
- driver → GoldenTestDriver
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scenario → String
-
final
- tester → WidgetTester
-
final
- variant → GoldenVariant
-
final
Methods
-
capture(
{String? testName}) → Future< void> -
elapse(
Duration duration) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
path(
{String? testName}) → String -
pumpFrames(
int count, {Duration step = const Duration(milliseconds: 16)}) → Future< void> -
pumpUntil(
GoldenWaitCondition condition, {Duration timeout = const Duration(seconds: 5), Duration step = const Duration(milliseconds: 16), String description = 'condition'}) → Future< void> -
pumpUntilFound(
Finder finder, {Duration timeout = const Duration(seconds: 5), Duration step = const Duration(milliseconds: 16)}) → Future< void> -
Pumps in bounded virtual-time steps until
finderappears. -
pumpUntilGone(
Finder finder, {Duration timeout = const Duration(seconds: 5), Duration step = const Duration(milliseconds: 16)}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited